@@ -10,7 +10,7 @@ utils::globalVariables(c(".", "%>%", ":="))
 }
 
 #' @importFrom magrittr %>%
-#' @importFrom data.table := %between% fifelse
+#' @importFrom data.table := %between% fifelse %chin%
 #' @importFrom stats na.omit
 #' @importFrom utils head tail object.size
 #' @importFrom stats na.omit
@@ -29,5 +29,5 @@ if(getRversion() >= "2.15.1") utils::globalVariables(
     '.N', 'update_newstoptimes', 'shape_pt_sequence', 'geometry',
     'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday',
     'service_duration', 'headway_secs', 'number_of_departures',
-    'cumtime', 'speed', 'i', 'route_type',
+    'cumtime', 'speed', 'i', 'route_type', 'trip_number',
     '.I', 'interval_id', 'i.interval', '.SD', 'grp', '.GRP'))
