@@ -1,9 +1,11 @@
 test_that("gtfs2gps", {
     poa <- system.file("extdata/poa.zip", package="gtfs2gps")
 
+    expect_warning(
     poa_gps <- read_gtfs(poa) %>%
       filter_week_days() %>%
-      gtfs2gps(parallel = FALSE)
+      gtfs2gps(parallel = FALSE),
+      "Trip '176-1@1#2310' has zero GPS points. Ignoring it.")
 
     #poa_shape <- read_gtfs(poa) %>% gtfs_shapes_as_sf()
     #plot(poa_shape)
@@ -15,24 +17,28 @@ test_that("gtfs2gps", {
     my_dim <- dim(poa_gps)[1]
     expect_equal(my_dim, 125718)
 
-    my_length <- length(poa_gps$dist[which(!poa_gps$dist < 50)])
+    my_length <- length(poa_gps$dist[which(!poa_gps$dist < units::set_units(50, "m"))])
     expect_equal(my_length, 0)
     
     expect_equal(sum(poa_gps$dist), 4065236, 0.001)
-    
+
+    expect_true(all(poa_gps$trip_number == 1))
+        
     expect_true(all(names(poa_gps) %in% 
-      c("trip_id", "route_type", "id", "shape_pt_lon", "shape_pt_lat",
+      c("trip_id", "route_type", "id", "shape_pt_lon", "shape_pt_lat", "trip_number",
         "departure_time", "stop_id", "stop_sequence", "dist", "shape_id", "cumdist", "speed", "cumtime")))
     
     expect_true(all(!is.na(poa_gps$dist)))
 
-    expect_true(all(poa_gps$dist > 0))
-    expect_true(all(poa_gps$speed > 0))
-    expect_true(all(poa_gps$cumtime > 0))
+    expect_true(all(poa_gps$dist > units::set_units(0, "m")))
+    expect_true(all(poa_gps$cumdist > units::set_units(0, "m")))
+    expect_true(all(poa_gps$speed > units::set_units(0, "km/h")))
+    expect_true(all(poa_gps$cumtime > units::set_units(0, "s")))
 
-    poa_gps_300 <- read_gtfs(poa) %>%
+    expect_warning(poa_gps_300 <- read_gtfs(poa) %>%
       filter_week_days() %>%
-      gtfs2gps(spatial_resolution = 300, parallel = FALSE, progress = FALSE)
+      gtfs2gps(spatial_resolution = 300, parallel = FALSE),
+      "Trip '176-1@1#2310' has zero GPS points. Ignoring it.")
     
     expect_equal(dim(poa_gps_300)[1], 66264)
     expect(dim(poa_gps_300)[1] < dim(poa_gps)[1], "more spatial_resolution is not decreasing the number of points")
@@ -41,10 +47,11 @@ test_that("gtfs2gps", {
     poa_simple <- read_gtfs(poa) %>%
       filter_by_shape_id(c("T2-1", "A141-1"))
 
-    poa_gps <- gtfs2gps(poa_simple, parallel = FALSE, progress = FALSE, filepath = ".")
+    poa_gps <- gtfs2gps(poa_simple, parallel = FALSE, filepath = ".")
     expect_null(poa_gps)
     
-    poa_gps <- gtfs2gps(poa, parallel = FALSE, progress = FALSE, filepath = ".", continue = TRUE)
+    expect_warning(poa_gps <- gtfs2gps(poa, parallel = FALSE, filepath = ".", continue = TRUE),
+                   "Trip '176-1@1#2310' has zero GPS points. Ignoring it.")
     
     expect_null(poa_gps)
     
@@ -64,16 +71,19 @@ test_that("gtfs2gps", {
       filter_by_shape_id(52000:52200) %>%
       filter_week_days() %>%
       filter_single_trip() %>%
-      gtfs2gps(parallel = FALSE, progress = TRUE, spatial_resolution = 15)
+      gtfs2gps(parallel = TRUE, spatial_resolution = 15)
 
     expect_true(all(names(sp_gps) %in% 
-      c("trip_id", "route_type", "id", "shape_pt_lon", "shape_pt_lat",
+      c("trip_id", "route_type", "id", "shape_pt_lon", "shape_pt_lat", "trip_number",
         "departure_time", "stop_id", "stop_sequence", "dist", "shape_id", "cumdist", "speed", "cumtime")))
 
+    expect_true(all(sp_gps$trip_number %in% 1:4))
+    
     my_dim <- dim(sp_gps)[1]
     expect_equal(my_dim, 286838)
 
-    expect_true(all(sp_gps$dist > 0))
-    expect_true(all(sp_gps$speed > 0))
-    expect_true(all(sp_gps$cumtime > 0))
+    expect_true(all(sp_gps$dist > units::set_units(0, "m")))
+    expect_true(all(sp_gps$cumdist > units::set_units(0, "m")))
+    expect_true(all(sp_gps$speed > units::set_units(0, "km/h")))
+    expect_true(all(sp_gps$cumtime > units::set_units(0, "s")))
 })
